#!/usr/bin/env python

import re

##
#
# Read a sumtime.html file and parse it into team scores.
# 
# Return None if parsing failed, a dictionary of team status
# if parsing succeeds

def _strint(score):
    if score == "--":
        return -1
    return int(score)

def parse_board(board_file):
    ret = {}
    f = open(board_file, "r")
    p = re.compile('<table[^>]*>(.*)</table>', re.DOTALL);
    # strip out html escaped characters
    m = p.search(re.sub("&....;", "", f.read()))
    if not m:
        return None
    lines = m.group(1).split("<tr>")[3:-2]
    for l in lines:
        cells = [re.sub("<[^>]*>", "", x) for x in l.split("</td>")[0:-2]]
        scores = tuple([tuple(map(_strint, x.split("/"))) for x in cells[1:-1]])
        ret[cells[0]] = scores
    return ret

# Do it the "right" way with an xml parser.  This seems to break horribly on pc^2
# 8.6 

#def parse_board(board_file):
#    ret = {}
#    try:
#        f = open(board_file, "r")
#        lines = re.sub("&nbsp;", "", f.read())
#        try:
#            tree = ElementTree.parse(StringIO.StringIO(lines))
#        except xml.parsers.expat.ExpatError:
#            return None
#    except IOError:
#        return None
#    root = tree.getroot()
#    rows = root.find("body").find("table").findall("tr")
#    i = 0
#    
#        # First two table rows are junk, as are the last two table rows.
#    for it in rows[2:-2]:
#        j = 0
#        team = it.find("td").text
#        # Last column is the sum, skip it
#        scores = tuple([ tuple(map(_strint, x.text.split("/"))) for x in it.findall("td")[1:-1]])
#        ret[team] = scores
#    return ret

if __name__ == "__main__":
    parse_board("sumtime.html")
